]> git.sesse.net Git - stockfish/blobdiff - src/tt.h
There is no need to clear TT at allocation time
[stockfish] / src / tt.h
index b43489dd796ebc8aff60902f12766b5ed5bedc7f..6833c67db0b36a2395a859a5033f79b64943e30c 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
 
 /// The TTEntry class is the class of transposition table entries
 ///
-/// A TTEntry needs 96 bits to be stored
+/// A TTEntry needs 128 bits to be stored
 ///
 /// bit  0-31: key
 /// bit 32-63: data
 /// bit 64-79: value
 /// bit 80-95: depth
+/// bit 96-111: static value
+/// bit 112-127: king danger value
 ///
 /// the 32 bits of the data field are so defined
 ///
@@ -115,10 +117,10 @@ public:
   TTEntry* first_entry(const Key posKey) const;
 
 private:
// Be sure 'writes' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];
-  unsigned writes; // heavy SMP read/write access here
+  unsigned overwrites; // heavy SMP read/write access here
   unsigned char pad_after[64];
 
   size_t size;
@@ -115,10 +117,10 @@ public:
 
 private:
-  // Be sure 'writes' is at least one cache line away
+  // Be sure 'overwrites' is at least one cache line away
   // from read only variables.
   unsigned char pad_before[64 - sizeof(unsigned)];